==> hguatlas13k.db_2.0.2.tar.gz: hguatlas13k.db/man/hguatlas13k_dbconn.Rd <==
\name{hguatlas13k_dbconn}

\alias{hguatlas13k_dbconn}
\alias{hguatlas13k_dbfile}
\alias{hguatlas13k_dbschema}
\alias{hguatlas13k_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  hguatlas13k_dbconn()
  hguatlas13k_dbfile()
  hguatlas13k_dbschema(file="", show.indices=FALSE)
  hguatlas13k_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{hguatlas13k_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{hguatlas13k_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{hguatlas13k_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{hguatlas13k_dbschema} prints the schema definition of the
  package annotation DB.

  \code{hguatlas13k_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{hguatlas13k_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{hguatlas13k_dbfile}: a character string with the path to the
  package annotation DB.

  \code{hguatlas13k_dbschema}: none (invisible \code{NULL}).

  \code{hguatlas13k_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(hguatlas13k_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by hguatlas13k_dbconn() was created with:
  dbConnect(SQLite(), dbname=hguatlas13k_dbfile(), cache_size=64000, synchronous=0)

  hguatlas13k_dbschema()

  hguatlas13k_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> hguatlas13k.db_2.7.1.tar.gz: hguatlas13k.db/man/hguatlas13k_dbconn.Rd <==

\name{hguatlas13k_dbconn}

\alias{hguatlas13k_dbconn}
\alias{hguatlas13k_dbfile}
\alias{hguatlas13k_dbschema}
\alias{hguatlas13k_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  hguatlas13k_dbconn()
  hguatlas13k_dbfile()
  hguatlas13k_dbschema(file="", show.indices=FALSE)
  hguatlas13k_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{hguatlas13k_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{hguatlas13k_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{hguatlas13k_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{hguatlas13k_dbschema} prints the schema definition of the
  package annotation DB.

  \code{hguatlas13k_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{hguatlas13k_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{hguatlas13k_dbfile}: a character string with the path to the
  package annotation DB.

  \code{hguatlas13k_dbschema}: none (invisible \code{NULL}).

  \code{hguatlas13k_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(hguatlas13k_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by hguatlas13k_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=hguatlas13k_dbfile(), cache_size=64000,
  synchronous=0)

  hguatlas13k_dbschema()

  hguatlas13k_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
